use chronoptics_tof as tof;
use tof::Camera;

fn capture_raw_frames(file_name: &str, nr_frames: usize) -> tof::Result<()> {
    let cameras = tof::discover_kea_cameras()?;
    if cameras.is_empty() {
        println!("No cameras detected");
        return Ok(());
    }

    let serial = cameras.first().unwrap().serial()?;
    let mut camera = tof::KeaCamera::new(&tof::ProcessingConfig::new_default()?, serial)?;

    // Disable on camera processing, otherwise raw frames aren't streamed from the camera
    camera.set_on_camera_processing(false)?;

    tof::select_streams(&camera, &[tof::FrameType::Raw])?;

    // Create a csf writer
    let mut csf_writer = tof::create_csf_writer_camera(file_name, &camera)?;

    camera.start()?;

    for i in 0..nr_frames {
        let frames = camera.get_frames()?;

        println!("Iteration {i}");

        for frame in frames {
            // Write raw frames to disk
            csf_writer.write_frame(&frame)?;
        }
    }

    Ok(())
}

fn main() {
    let file_name = "raw_frames.csf";
    let nr_frames = 100;
    let ret = capture_raw_frames(file_name, nr_frames);

    match ret {
        Ok(_) => println!("Succesfully captured {nr_frames} frames"),
        Err(err) => println!("Failed with {err}"),
    }
}
